/*
    hashSum
    Copyright (C) 2011-2018 Ingemar Ceicer
    http://ceicer.org/
    programmering1 (at) ceicer (dot) org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
*/

#ifndef HASH_H
#define HASH_H

#include <string>
#include <sstream>
#include <fstream>
#include "checkforupdates.h"
#include "config.h"
#include "extqlineedit.h"
#include <QSysInfo>
#include <QtWidgets>
#include <QTextCodec>

/* draganddrop */
#include <QDropEvent>
#include <QUrl>
#include <QDebug>



#define VERSION_PATH "http://bin.ceicer.com/hash/version.txt"
#define APPLICATION_NAME "hashSum"
#define EXECUTABLE_NAME "hashsum"
#define VERSION "2.3.2"
#define BUILD_DATE_TIME __DATE__ " " __TIME__
#define CURRENT_YEAR "2018"
#define LICENCE_VERSION "3"
#define PROGRAMMER_EMAIL "programmering1@ceicer.org"
#define PROGRAMMER_NAME "Ingemar Ceicer"
#define PROGRAMMER_PHONE "+46706361747"
#define APPLICATION_HOMEPAGE "http://ceicer.org/hash/index.php"
#define APPLICATION_HOMEPAGE_ENG "http://ceicer.org/hash/index_eng.php"
#define elGR_TRANSLATOR "www.geogeo.gr"
#define deDE_TRANSLATOR "Benjamin Weis"

#define QLINEEDIT_MAX 32767
#define SIZE_OF_RECENT_FILES 50




namespace Ui
{
class Hash;
}
namespace Ui
{
class Lic;
}

class Hash : public QMainWindow
{
    Q_OBJECT

public:
    explicit Hash(QWidget *parent = nullptr);
    ~Hash();


protected:
    /* draganddrop */
    void dropEvent(QDropEvent *ev);
    void dragEnterEvent(QDragEnterEvent *ev);


private:
    Ui::Hash *ui;
    Ui::Lic *ui2;
    Config  *k;
    QDialog *d;

    void setStartConfig();
    void setEndConfig();
    bool doChecksum(QString);
    bool doChecksum(QString, QStringList *lista);
    bool doChecksumText(const QString);
    bool doChecksumList(QString, QString &, std::string);
    bool doCompare(QString, QString);
    bool askForFileName(QString, std::string, QStringList);
    bool askForFileNameCheck(QString, std::string, QStringList);
    bool dontAskForFileName(std::string, QStringList);
    QString datumtid();
    bool rekursivt(QDir, QString);
    bool rekursivtPrint(QString, QString, QDir, std::string);
    int hurmangaFoldrar;
    void checkSumList(int);
    int hurmangaFiler;
    bool createDeb(QString sokvag2, QStringList fileNames);
    QString getSystem();
    bool rekursivtDeb(QDir path, QString &indent, QStringList &allt);
    bool rekursivtPrintDeb(QDir path, QStringList &allt);

    bool recentFileList(QString);
    QStringList recentFiles;
    int MAX_RECENT_FILES;

    QStringList algoritmer;
    QStringList *lista;


private slots:
    void checkForUpdates();
    void about();
    void checkOnStart();
    void saveChecksumListWhereFilesAre();
    void md4();
    void md5();
    void sha1();

    void sha224();
    void sha256();
    void sha384();
    void sha512();
    void sha3_224();
    void sha3_256();
    void sha3_384();
    void sha3_512();

    void keccak_224();
    void keccak_256();
    void keccak_384();
    void keccak_512();


    void compare();
    void checksum();

    void swedish();
    void english();
    void german();
    void greek();
    void checkSumListInit();
    void checkSumLists();
    void compareGivenHashSum();
    void defaultFileName();
    void writeTimeDateInHashSumFile();
    void findChangedFiles();
    void useNativeDialogs();
    void allwaysOpenHomeDirectory();
    void copyPath();
    void copyHashSum();
    void hashSumText();
    void compareHashSumText();
    void help();
    void license();
    void versionhistory();
    void createDebianMd5sums();
    void createDebianMd5sumsAuto();
    void showFullPathInHashSumFile();

    void slotRecentFiles();
    void recentFileRequested(const QString path);
    void setRecentFiles();
    void clearRecentFiles();
    void stang();

    void openHashSumList();
    void openComparisonList();
    void openFile();

    void save();
    void saveOne();


public slots:


};

#endif // HASH_H
